package com.gic.haoban.manage.web.controller.content;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.GICMQClientUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.haoban.app.customer.dto.CustomerDTO;
import com.gic.haoban.app.customer.dto.MemberInfoListParamsDTO;
import com.gic.haoban.app.customer.service.api.service.DistributeApiService;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.web.controller.WebBaseController;
import com.gic.haoban.manage.web.qo.CustomerQO;
import com.gic.haoban.manage.web.utils.ClerkUtils;

@RestController
public class QwMessageController extends WebBaseController {
    private final Logger logger = LogManager.getLogger(QwMessageController.class);
    @Autowired
    private DistributeApiService distributeApiService;
    @Autowired
    private StaffApiService staffApiService;
    @Autowired
    private ClerkService clerkService;

    /**
     *  群发-分享
     */
    @RequestMapping("/message-send")
    public RestResponse<Object> messageSend(CustomerQO qo, String imgJson, String selectedStoreId) {
        CustomerDTO params = EntityUtil.changeEntityByJSON(CustomerDTO.class, qo);
        String clerkId = qo.getClerkId();
        String wxEnterpriseId = qo.getWxEnterpriseId();
        String enterpriseId = qo.getEnterpriseId();
        String searchParams = qo.getSearchParams();
        String staffId = qo.getStaffId();
        List<String> memberIdList = qo.getMemberIdList();
        ClerkDTO clerk = this.clerkService.getclerkById(clerkId);
        String storeId = ClerkUtils.getClerkStore(clerk, clerkId, selectedStoreId);
        // 店长参数
        params.setStoreId(storeId);
        params.setEnterpriseId(enterpriseId);
        params.setClerkId(clerkId);
        MemberInfoListParamsDTO memberInfoListParamsDTO = com.gic.haoban.common.utils.StringUtil.getBean(searchParams,
                MemberInfoListParamsDTO.class);
        params.setQwFriendFlag(true);
        List<String> sendMemberIds = distributeApiService.getMemberIds(params, memberIdList, memberInfoListParamsDTO);
        if (CollectionUtils.isEmpty(sendMemberIds)) {
            return RestResponse.failure("-1","无会员数据");
        }
        List<String> staffIdList = new ArrayList<>();
        if (clerk.getClerkType() == 1) {
            staffIdList = staffApiService.listBindStaffId(storeId);
        } else if(clerk.getClerkType()==0) {
            staffIdList.add(clerkId);
        }
        if(CollectionUtils.isEmpty(staffIdList)) {
            return RestResponse.failure("-1","无成员数据");
        }
        JSONObject json = new JSONObject();
        json.put("userIdList", staffIdList);
        json.put("sendMemberIds", sendMemberIds);
        json.put("enterpriseId", enterpriseId);
        json.put("imgJson", imgJson);
        json.put("storeId", storeId);
        json.put("staffId", staffId);
        // 群发-分享
        json.put("sendType", 1);
        json.put("wxEnterpriseId", wxEnterpriseId);
        String ret = json.toJSONString();
        try {
            GICMQClientUtil.getClientInstance().sendCommonMessage("haobanCommonRouter", ret,
                    "com.gic.haoban.app.customer.service.api.service.MessageLogApiService", "callBackSendMessage");
        } catch (Exception e) {
            logger.info(e.getMessage(), e);
        }
        return RestResponse.successResult();
    }
    
    // 朋友圈任务
    @RequestMapping("/add_moment_task")
    public RestResponse<Object> share(CustomerQO qo, String imgJson) {
        String clerkId = qo.getClerkId();
        String wxEnterpriseId = qo.getWxEnterpriseId();
        String enterpriseId = qo.getEnterpriseId();
        String staffId = qo.getStaffId();
        List<String> clerkIdList = qo.getClerkIdList() ;
        ClerkDTO clerk = this.clerkService.getclerkById(clerkId);
        logger.info("clerkType={},ChooseAll={}",clerk.getClerkType(),qo.getChooseAll());
        // 查询所有门店-导购
        if(StringUtils.isNotBlank(qo.getChooseAll()) && "1".equals(qo.getChooseAll())) {
            if (clerk.getClerkType() == 1) {
                String storeId = clerk.getStoreId() ;
                clerkIdList = staffApiService.listBindStaffId(storeId);
                logger.info("店长,导购数={}",clerkIdList.size());
            } else if(clerk.getClerkType()==2) {
                // 区经
            } else {
                clerkIdList = new ArrayList<>();
            }
        }
        logger.info("clerkIdList={}",JSON.toJSONString(clerkIdList));
        if(CollectionUtils.isEmpty(clerkIdList)) {
            return RestResponse.failure("-1","无发送导购数据");
        }
        JSONObject json = new JSONObject();
        json.put("clerkIdList", clerkIdList);
        json.put("enterpriseId", enterpriseId);
        json.put("imgJson", imgJson);
        json.put("staffId", staffId);
        // 朋友圈-分享
        json.put("sendType", 2);
        json.put("wxEnterpriseId", wxEnterpriseId);
        json.put("content", qo.getContent()) ;
        String ret = json.toJSONString();
        try {
            GICMQClientUtil.getClientInstance().sendCommonMessage("haobanCommonRouter", ret,
                    "com.gic.haoban.app.customer.service.api.service.MessageLogApiService", "callBackSendMessage");
        } catch (Exception e) {
            logger.info(e.getMessage(), e);
        }
        return RestResponse.successResult();
    }

}
